==> production-demo-20260209_092157.tar.gz: var/www/html/production-demo/var/tmp/twig/65/657eed8042b76cb6acd00a0e5dd57877.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/paprika/assets/twitter.png */
class __TwigTemplate_fad0d973e8138eecc663826da5fab256 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000\000\000\000\000h\000\000\000sRGB\000\000\000\000gAMA\000\000a\000\000\000PLTE+..),3610599>==81064=:-),07:BFFIIINLMBAAEEKAEAADEFDHIMNLHILMQUPQRQVUUY]]\\[QUTZ]RQRVTUVQQTRRSVUYXY]]]\\]]YY]^__@BFJIMJRYddjaeddioa`adefca`abdeeinimmlihlmmr|qtyy~{ppuuszOS_T]gkpqtuuy{z|}}}bcgbjihmmmmhjlbk`glmrqqttttyy}~|{psqutvvy}xǍńфׂـ݀݃\$~\000\000\000\tpHYs\000\000\000\000od\000\000ZIDATx^[kE6w;;yݙ-f.FVP
>Help-)17D@LiEB!PE4j->
QA\$b|aFJu<;`g3tOקO>yZ
+\$V8HpX q~skw8j}ͳwes/xqQ4<|\tkOG~r.<Ƣ5YkXj/48cyîPUO|<I[wkh0ln-0;dW|EUw{W>|~[8WUQ}:c3q4ڃ=wqJ7;AG\000
 |/0[8a\tn^r':0bOI,N~,t;kKtaO
^+ CQT9<pk[taQ%H\000dL6%azB>x·.\tP]Fp]MA+?+Q;Diz/~T<o5yakam¨@\\w6hUj\000t@[6N=ן2lj.-rA-`xA3Gj,L}#8;F=@%\\Y2p-,c\000[
14}T/ iD[9_u\tXUVha0nS[`s
r\\ŲrpaqdeݜSm\000]hmUQ!Rv\"=,'CT6˲rQ4Lmǜ``KV4ǢbrډYk]R?m|VҊ8lU%d\t{qƴF!<K{9KPa
!cNW,6\00065HM ,wS5)=Ò<
9lG/OqC̈́2|QѶ\$\"3:BbC\\Qz*2Oj]Jx+K2(0.=|7bsl <}:Gpݜl.bsREh儣HV88Kj %xA}Xavk#c
!'T߫XE#,^բN\tN|lRQ+sj*11QE&
0Sa1==7!ɈJ
IFO+\"oYh\tdŝaK3~Ox4aҥidq,aU(ax7J!*Y,Sa%J1e\"nkZUPbܴ?`gF9)\t Lx|EÄE/|
GIL+֙,h\"ᐾ
I
خ=87D''|b{<L]rDvxf8l5\0008atfo(ޭQ\t«俕OFè\\+Jp\t&,WK0J,#x\tod`FڦPg4jSs5tlH!ocװdx>8<4&1+i/p&͸Oh`eSQy3RnMr`%2p}Lyyi/0F;2Z~U;l~:2uN[љ0v,D6X¬#8`ӕ3恶Fg*xaTuŅ0ܑ (ఫ.GH7/!ev\\4}_:1+3?<M74|i~i\"W
>\"!lDE4\"
CҠ\$RBF\000䴷t)4{
4By\"8  Ec̴Yn_ϸ+8POq8v@7CѼ0UWȚh>aE28#ܪE|pwfeo>>f{@=lY@HsֱH
,C2W9Z&!YkSjNM/C{(N-\$لkG|tCr='37rxg/KqCQa3^-!?p8 Xҫ&Rkc2Ы28d 

Wwі%dtg\t!!Y+hk/&i\\V5.µ0ҁJ:Js#7D4\tWwnLgDX\"c[|,=;kB,PpO\\ڵ7
!]IΗc p
\000b%;
芴3TU6h=xMM]N!\"P9ǟClYCKG9\000\"K9_sSøj=y2EȾ(⠒tt1(jcÌ]GZd^=+cRohxf?!אH5˪ɇC9{2/k^(Gsdˮ`FgwWxlRaq1hzXpFF\"hʐ^FZ;ٓ[(Jp,CJ\\*q\000W倾q~m&MaϰJV/\t;ȩ8K.p89zoK\000OJ\"\000\000ķ2\0004nJfzFYj\000
9*.<1S3(y*f,';e[Pȿ}yK^&·X\t~ ,9n;)F=a.-~2nz<@G_LzOF(l=n5gp?oue~x\"iT4۶MlM;{V5:Cγ}1#ϟAPsppR|qƁF#n&,8 h=yΩuokz<6\tI,h؝a6N
I-AC2ڳ;L
GF}G85I-EnF^P_Xz/3ik\000YZQQ9ɀOr=Q5,]0C<5`DΝ<.Ül\\'f\000yIylӹ0\\Lհn)65]4
8?sn1jt\tƸQ3KNpHvPrǛvN~3V+@5QrHٖ\$}n|(_OPrH^dHb*];u:?\000i)3K8\\0:ЬpL1,3K8\$f8\$B?-e1g/H\t\000B926%r;>}ȡh#\000%9&S<4ᚼk6e
pA.]yIqHh<,
yE1;\\3A3AR[O盃#JV (NJaPVcw]͉eh!e|S2\$LUEcg~O7jxSG|n|D<0VR0]-
FZ0N3ƘCo
q\00077;>IUj*sU`O;K6 ўCrɇp0,Q\tD>uEvd|8CrMM|4!\\v8UA'`yWaMh.8e|:&:М&H@ѴNU@Crqcr]umCumX|9؉!r\000UdM
Sɧ8}-MN^zm3CrsC2t
80}/<CTS9Ab
+\$V8HpXHuV\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/paprika/assets/twitter.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/paprika/assets/twitter.png", "/var/www/html/mauticGIT-Test/themes/paprika/assets/twitter.png");
    }
}

==> production-demo-20260210_204327.tar.gz: var/www/html/production-demo/var/tmp/twig/65/657eed8042b76cb6acd00a0e5dd57877.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/paprika/assets/twitter.png */
class __TwigTemplate_fad0d973e8138eecc663826da5fab256 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000\000\000\000\000h\000\000\000sRGB\000\000\000\000gAMA\000\000a\000\000\000PLTE+..),3610599>==81064=:-),07:BFFIIINLMBAAEEKAEAADEFDHIMNLHILMQUPQRQVUUY]]\\[QUTZ]RQRVTUVQQTRRSVUYXY]]]\\]]YY]^__@BFJIMJRYddjaeddioa`adefca`abdeeinimmlihlmmr|qtyy~{ppuuszOS_T]gkpqtuuy{z|}}}bcgbjihmmmmhjlbk`glmrqqttttyy}~|{psqutvvy}xǍńфׂـ݀݃\$~\000\000\000\tpHYs\000\000\000\000od\000\000ZIDATx^[kE6w;;yݙ-f.FVP
>Help-)17D@LiEB!PE4j->
QA\$b|aFJu<;`g3tOקO>yZ
+\$V8HpX q~skw8j}ͳwes/xqQ4<|\tkOG~r.<Ƣ5YkXj/48cyîPUO|<I[wkh0ln-0;dW|EUw{W>|~[8WUQ}:c3q4ڃ=wqJ7;AG\000
 |/0[8a\tn^r':0bOI,N~,t;kKtaO
^+ CQT9<pk[taQ%H\000dL6%azB>x·.\tP]Fp]MA+?+Q;Diz/~T<o5yakam¨@\\w6hUj\000t@[6N=ן2lj.-rA-`xA3Gj,L}#8;F=@%\\Y2p-,c\000[
14}T/ iD[9_u\tXUVha0nS[`s
r\\ŲrpaqdeݜSm\000]hmUQ!Rv\"=,'CT6˲rQ4Lmǜ``KV4ǢbrډYk]R?m|VҊ8lU%d\t{qƴF!<K{9KPa
!cNW,6\00065HM ,wS5)=Ò<
9lG/OqC̈́2|QѶ\$\"3:BbC\\Qz*2Oj]Jx+K2(0.=|7bsl <}:Gpݜl.bsREh儣HV88Kj %xA}Xavk#c
!'T߫XE#,^բN\tN|lRQ+sj*11QE&
0Sa1==7!ɈJ
IFO+\"oYh\tdŝaK3~Ox4aҥidq,aU(ax7J!*Y,Sa%J1e\"nkZUPbܴ?`gF9)\t Lx|EÄE/|
GIL+֙,h\"ᐾ
I
خ=87D''|b{<L]rDvxf8l5\0008atfo(ޭQ\t«俕OFè\\+Jp\t&,WK0J,#x\tod`FڦPg4jSs5tlH!ocװdx>8<4&1+i/p&͸Oh`eSQy3RnMr`%2p}Lyyi/0F;2Z~U;l~:2uN[љ0v,D6X¬#8`ӕ3恶Fg*xaTuŅ0ܑ (ఫ.GH7/!ev\\4}_:1+3?<M74|i~i\"W
>\"!lDE4\"
CҠ\$RBF\000䴷t)4{
4By\"8  Ec̴Yn_ϸ+8POq8v@7CѼ0UWȚh>aE28#ܪE|pwfeo>>f{@=lY@HsֱH
,C2W9Z&!YkSjNM/C{(N-\$لkG|tCr='37rxg/KqCQa3^-!?p8 Xҫ&Rkc2Ы28d 

Wwі%dtg\t!!Y+hk/&i\\V5.µ0ҁJ:Js#7D4\tWwnLgDX\"c[|,=;kB,PpO\\ڵ7
!]IΗc p
\000b%;
芴3TU6h=xMM]N!\"P9ǟClYCKG9\000\"K9_sSøj=y2EȾ(⠒tt1(jcÌ]GZd^=+cRohxf?!אH5˪ɇC9{2/k^(Gsdˮ`FgwWxlRaq1hzXpFF\"hʐ^FZ;ٓ[(Jp,CJ\\*q\000W倾q~m&MaϰJV/\t;ȩ8K.p89zoK\000OJ\"\000\000ķ2\0004nJfzFYj\000
9*.<1S3(y*f,';e[Pȿ}yK^&·X\t~ ,9n;)F=a.-~2nz<@G_LzOF(l=n5gp?oue~x\"iT4۶MlM;{V5:Cγ}1#ϟAPsppR|qƁF#n&,8 h=yΩuokz<6\tI,h؝a6N
I-AC2ڳ;L
GF}G85I-EnF^P_Xz/3ik\000YZQQ9ɀOr=Q5,]0C<5`DΝ<.Ül\\'f\000yIylӹ0\\Lհn)65]4
8?sn1jt\tƸQ3KNpHvPrǛvN~3V+@5QrHٖ\$}n|(_OPrH^dHb*];u:?\000i)3K8\\0:ЬpL1,3K8\$f8\$B?-e1g/H\t\000B926%r;>}ȡh#\000%9&S<4ᚼk6e
pA.]yIqHh<,
yE1;\\3A3AR[O盃#JV (NJaPVcw]͉eh!e|S2\$LUEcg~O7jxSG|n|D<0VR0]-
FZ0N3ƘCo
q\00077;>IUj*sU`O;K6 ўCrɇp0,Q\tD>uEvd|8CrMM|4!\\v8UA'`yWaMh.8e|:&:М&H@ѴNU@Crqcr]umCumX|9؉!r\000UdM
Sɧ8}-MN^zm3CrsC2t
80}/<CTS9Ab
+\$V8HpXHuV\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/paprika/assets/twitter.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/paprika/assets/twitter.png", "/var/www/html/production-demo/themes/paprika/assets/twitter.png");
    }
}
